rm(list = ls())
ls()
library(readxl)
library(stats)
library(coefplot)
library(car)
library(corrplot)


setwd("/Users/edmundaslapenas/Desktop/Progress Master")

data_article_8_9 <- "Article8&9_R_Data.xlsx"
data_article_8_9 <- read_excel(data_article_8_9)
head(data_article_8_9)
summary(data_article_8_9)

data_article_8_9 <- na.omit(data_article_8_9)
summary(data_article_8_9)

data_index <- "Index_Funds_New_Data.xlsx"
data_index  <- read_excel(data_index)
head(data_index)
summary(data_index)

cor_matrix_box_article <- cor(data_article_8_9[, c("Portfolio Sustainability Score",
                                                   "Portfolio Environmental Score",
                                                   "Portfolio Social Score",
                                                   "Portfolio Governance Score",
                                                   "Carbon Intensity",
                                                   "Emissions Scope 1",
                                                   "Emissions Scope 2",
                                                   "Percent of Female Executives and Directors",
                                                   "Water Withdrawal Intensity Average")], use = "complete.obs")


corrplot(cor_matrix_box_article, method = "circle", tl.col = "black")

######## short names for better visual representation #########

# Make a copy of your original dataframe for this specific plot
temp_data_article <- data_article_8_9

# Change column names to abbreviations
names(temp_data_article)[names(temp_data_article) %in% c("Portfolio Sustainability Score",
                                                         "Portfolio Environmental Score",
                                                         "Portfolio Social Score",
                                                         "Portfolio Governance Score",
                                                         "Carbon Intensity",
                                                         "Emissions Scope 1",
                                                         "Emissions Scope 2",
                                                         "Percent of Female Executives and Directors",
                                                         "Water Withdrawal Intensity Average")] <- c("PSS", "PES", "PSSoc", "PGS", "CI", "ES1", "ES2", "PFED", "WWIA")

# Calculate correlation
cor_matrix_box_article <- cor(temp_data_article[, c("PSS", "PES", "PSSoc", "PGS", "CI", "ES1", "ES2", "PFED", "WWIA")], use = "complete.obs")

# Generate plot
corrplot(cor_matrix_box_article, method = "circle", tl.col = "black")

cor_matrix_box_article <- cor(temp_data_article[, c("PSS", "PES", "PSSoc", "PGS", "CI", "ES1", "ES2", "PFED", "WWIA")], use = "complete.obs")
print(cor_matrix_box_article)

################### Regression analysis of sustainability ratings  Article 8 and 9 funds ###############

model_article_8_9 <- lm(data_article_8_9$`Portfolio Sustainability Score` ~ data_article_8_9$`Portfolio Environmental Score`
                        + data_article_8_9$`Portfolio Social Score`
                        + data_article_8_9$`Portfolio Governance Score`
                        + data_article_8_9$`Carbon Intensity`
                        + data_article_8_9$`Emissions Scope 1`
                        + data_article_8_9$`Emissions Scope 2`
                        + data_article_8_9$`Percent of Female Executives and Directors`
                        + data_article_8_9$`Water Withdrawal Intensity Average`, data = data_article_8_9)

summary(model_article_8_9)
residuals_article_8_9 <- model_article_8_9$residuals
fitted_values_article_8_9 <- model_article_8_9$fitted.values

plot(fitted_values_article_8_9, residuals_article_8_9, main = "Residual Plot", xlab = "Fitted Values", ylab = "Residuals")
abline(h = 0, col = "red")

vif_values <- vif(model_article_8_9)
print(vif_values)

hist(residuals_article_8_9, main = "Histogram of Residuals", xlab = "Residuals")

############################### Regression analysis of sustainability ratings Index Funds ################################

####### Correlation analysis #########

# Make a copy of your original dataframe for this specific plot
temp_data_index <- data_index

# Change column names to abbreviations
names(temp_data_index)[names(temp_data_index) %in% c("Portfolio Corporate Sustainability Score",
                                                     "Portfolio Environmental Risk Score", 
                                                     "Portfolio Social Risk Score", 
                                                     "Portfolio Governance Risk Score", 
                                                     "Water Withdrawal Intensity Average",
                                                     "Portfolio Carbon Risk Score", 
                                                     "Percent of Female Executives and Directors")] <- 
  c("PCSS","PERS", "PSRS", "PGRS", "WWIA", "PCRS", "PFED")

# Calculate correlation
cor_matrix_index <- cor(temp_data_index[, c("PCSS", "PSRS", "PGRS", "WWIA", "PCRS", "PFED")], use = "complete.obs")

# Generate plot
corrplot(cor_matrix_index, method = "circle", tl.col = "black")

# Print correlation matrix
cor_matrix_index <- cor(temp_data_index[, c("PCSS", "PSRS", "PGRS", "WWIA", "PCRS", "PFED")], use = "complete.obs")
print(cor_matrix_index)

##################################################################

model_index_carbon_water <- lm(`Portfolio Corporate Sustainability Score` ~ `Portfolio Carbon Risk Score` 
                               + `Portfolio Social Risk Score`
                               + `Portfolio Governance Risk Score`
                               + `Water Withdrawal Intensity Average`
                               + `Percent of Female Executives and Directors`, data = data_index)
summary(model_index_carbon_water)
vif(model_index_carbon_water)

aic_cw <- AIC(model_index_carbon_water)
print(paste("AIC for the cw model: ", aic_cw))
bic_cw <- BIC(model_index_carbon_water)
print(paste("BIC for the cw model: ", bic_cw))

# Residuals plot
residuals_cw <- resid(model_index_carbon_water)
plot(residuals_cw, main = "Residuals Plot", ylab = "Residuals", xlab = "Fitted values")
abline(h = 0, col = "red")

# Histogram of residuals
hist(residuals_cw, main = "Histogram of Residuals", xlab = "Residuals")

dwtest(model_index_carbon_water)
library(forecast)
Acf(residuals_cw, main="Autocorrelation of Residuals")

# Shapiro-Wilk Normality Test
shapiro.test(residuals(model_index_carbon_water))

######################## Sustainability rating comparison given one time period #####################################

data_sust.ratings <- data.frame(
  sustainability_rating = c(data_article_8_9$`Portfolio Sustainability Score`, data_index$`Portfolio Corporate Sustainability Score`),
  fund_type = c(rep("Article 8 and 9", length(data_article_8_9$`Portfolio Sustainability Score`)), rep("Index", length(data_index$`Portfolio Corporate Sustainability Score`)))
)

summary_article_8_and_9 <- summary(data_sust.ratings$sustainability_rating[data_sust.ratings$fund_type == "Article 8 and 9"])
summary_index <- summary(data_sust.ratings$sustainability_rating[data_sust.ratings$fund_type == "Index"])

cat("Summary statistics for Article 8 and 9 funds:\n")
print(summary_article_8_and_9)
cat("\n")
cat("Summary statistics for index funds:\n")
print(summary_index)

boxplot(sustainability_rating ~ fund_type, data = data_sust.ratings, main = "Sustainability Ratings Comparison", ylab = "Sustainability Rating", xlab = "Fund Type", col = c("lightblue", "lightgreen"), notch = TRUE)

################# Statistical significance test between Sustainability ratings ###################

result <- wilcox.test(sustainability_rating ~ fund_type, data = data_sust.ratings, exact = FALSE)
print(result)
